@@ -1084,11 +1084,15 @@ setMethod("extract", signature = className("maBina", "erer"),
     definition = extract.maBina)
 
 
-# extension for mer (and lmerMod, glmerMod and nlmerMod) objects (lme4 package)
-extract.mer <- function(model, include.pvalues = TRUE, include.aic = TRUE, 
-    include.bic = TRUE, include.loglik = TRUE, include.deviance = TRUE, 
-    include.nobs = TRUE, include.groups = TRUE, include.variance = TRUE, 
-    mcmc = FALSE, mcmc.size = 5000, conf.level = 0.95, ...) {
+# extension for lme4 (+ mer, lmerMod, glmerMod, nlmerMod) objects (lme4 package)
+extract.lme4 <- function(model, naive = FALSE, nsim = 1000, conf.level = 0.95, 
+    include.aic = TRUE, include.bic = TRUE, include.loglik = TRUE, 
+    include.deviance = TRUE, include.nobs = TRUE, include.groups = TRUE, 
+    include.variance = TRUE, ...) {
+  
+  if (packageVersion("lme4") < 1.0) {
+    message("Please update to a newer 'lme4' version for full compatibility.")
+  }
   
   gof <- numeric()
   gof.names <- character()
@@ -1126,13 +1130,13 @@ extract.mer <- function(model, include.pvalues = TRUE, include.aic = TRUE,
   if (include.groups == TRUE) {
     grps <- sapply(model@flist, function(x) length(levels(x)))
     grp.names <- names(grps)
-    grp.names <- paste("Num. groups:", grp.names)
+    grp.names <- paste("Num.\ groups:", grp.names)
     gof <- c(gof, grps)
     gof.names <- c(gof.names, grp.names)
     gof.decimal <- c(gof.decimal, rep(FALSE, length(grps)))
   }
   if (include.variance == TRUE) {
-    vc <- VarCorr(model)
+    vc <- lme4::VarCorr(model)
     varcomps <- c(unlist(lapply(vc, diag)),   # random intercept variances
         attr(vc, "sc")^2)                     # residual variance
     varnames <- names(varcomps)
@@ -1147,43 +1151,48 @@ extract.mer <- function(model, include.pvalues = TRUE, include.aic = TRUE,
     gof.decimal <- c(gof.decimal, rep(TRUE, length(varcomps)))
   }
   
-  betas <- fixef(model, ...)
-  if (mcmc == TRUE && exists("mcmcsamp")) {
-    m <- asS4(model)
-    mcmc <- lme4::mcmcsamp(m, n = mcmc.size)
-    hpd <- HPDinterval(mcmc, prob = conf.level)
-    ci.l <- hpd$fixef[, 1]
-    ci.u <- hpd$fixef[, 2]
-    
-    tr <- createTexreg(
-        coef.names = names(betas), 
-        coef = betas, 
-        se = numeric(0),
-        pvalues = numeric(0),
-        ci.low = ci.l,
-        ci.up = ci.u,
-        gof.names = gof.names,
-        gof = gof,
-        gof.decimal = gof.decimal
+  betas <- lme4::fixef(model, ...)
+  if ("confint.merMod" %in% methods("confint")) {
+    ci <- tryCatch({
+        ci <- confint(model, level = conf.level, nsim = nsim, ...)
+      },
+      error = function(err) {
+        naive <- TRUE
+        message(paste("Confidence intervals not available for", 
+            "this model. Using naive p values instead."))
+      }
     )
-  } else {
-    if (!exists("mcmcsamp")) {
-      warning(paste0("MCMC sampling not available in this lme4 version. ",
-          "Using standard errors and naive p values instead. Note that the p ",
-          "values may thus be inaccurate."))
-    } else if (include.pvalues == TRUE) {
-      cat(paste("Computing naive p values. Look at the help page of",
-          "extract.mer for details on MCMC confidence intervals.\n"))
+    if (is.null(ci)) {
+      naive <- TRUE
+    } else {
+      message(paste0("Computing confidence intervals at a confidence ",
+          "level of ", conf.level, ". Use ", 
+          "argument \"method = 'boot'\" for bootstrapped CIs."))
+      last <- nrow(ci)
+      number <- length(betas)
+      first <- last - number + 1
+      ci <- ci[first:last, ]
+      if (class(ci) == "matrix") {
+        ci.l <- ci[, 1]
+        ci.u <- ci[, 2]
+      } else {
+        ci.l <- ci[1]
+        ci.u <- ci[2]
+      }
+      naive <- FALSE
     }
+  } else {
+    naive <- TRUE
+    message(paste("confint.merMod method not found. Using naive p values",
+        "instead."))
+  }
+  
+  if (naive == TRUE) {
     Vcov <- vcov(model, useScale = FALSE, ...)
     Vcov <- as.matrix(Vcov)
     se <- sqrt(diag(Vcov))
-    if (include.pvalues == FALSE) {
-      pval <- numeric(0)
-    } else {  # naive p-values
-      zval <- betas / se
-      pval <- 2 * pnorm(abs(zval), lower.tail = FALSE)
-    }
+    zval <- betas / se
+    pval <- 2 * pnorm(abs(zval), lower.tail = FALSE)
     
     tr <- createTexreg(
         coef.names = names(betas), 
@@ -1194,22 +1203,37 @@ extract.mer <- function(model, include.pvalues = TRUE, include.aic = TRUE,
         gof = gof,
         gof.decimal = gof.decimal
     )
-    return(tr)
+  } else {
+    tr <- createTexreg(
+        coef.names = names(betas), 
+        coef = betas, 
+        ci.low = ci.l,
+        ci.up = ci.u,
+        gof.names = gof.names,
+        gof = gof,
+        gof.decimal = gof.decimal
+    )
   }
+  
+  return(tr)
 }
 
+setMethod("extract", signature = className("lme4", "lme4"), 
+    definition = extract.lme4)
+
+extract.mer <- extract.lme4
 setMethod("extract", signature = className("mer", "lme4"), 
     definition = extract.mer)
 
-extract.lmerMod <- extract.mer
+extract.lmerMod <- extract.lme4
 setMethod("extract", signature = className("lmerMod", "lme4"), 
     definition = extract.lmerMod)
 
-extract.glmerMod <- extract.mer
+extract.glmerMod <- extract.lme4
 setMethod("extract", signature = className("glmerMod", "lme4"), 
     definition = extract.glmerMod)
 
-extract.nlmerMod <- extract.mer
+extract.nlmerMod <- extract.lme4
 setMethod("extract", signature = className("nlmerMod", "lme4"), 
     definition = extract.nlmerMod)
 
@@ -1600,6 +1624,48 @@ setMethod("extract", signature = className("rq", "quantreg"),
     definition = extract.rq)
 
 
+# extension for sienaFit objects (RSiena package)
+extract.sienaFit <- function(model, include.iterations = TRUE, ...) {
+  
+  s <- summary(model, ...)
+  
+  #rate.names <- attributes(summary(model)$f)$condEffects[, 1]
+  rate.names <- paste("Rate parameter period", 1:length(model$rate))
+  theta.names <- s$effects$effectName
+  coef.names <- c(rate.names, theta.names)
+  
+  coefs <- c(model$rate, model$theta)
+  
+  se <- c(model$vrate, sqrt(diag(model$covtheta)))
+  
+  pval <- pval <- 2 * pnorm(-abs(coefs / se))
+  
+  gof <- numeric()
+  gof.names <- character()
+  gof.decimal <- logical()
+  if (include.iterations == TRUE) {
+    n <- s$n
+    gof <- c(gof, n)
+    gof.names <- c(gof.names, "Iterations")
+    gof.decimal <- c(gof.decimal, FALSE)
+  }
+  
+  tr <- createTexreg(
+    coef.names = coef.names, 
+    coef = coefs, 
+    se = se,
+    pvalues = pval, 
+    gof.names = gof.names, 
+    gof = gof, 
+    gof.decimal = gof.decimal
+  )
+  return(tr)
+}
+
+setMethod("extract", signature = className("sienaFit", "RSiena"), 
+    definition = extract.sienaFit)
+
+
 # extension for simex objects
 extract.simex <- function(model, jackknife = TRUE, include.nobs = TRUE, ...) {
   s <- summary(model, ...)
@@ -2009,6 +2075,8 @@ extract.texreg <- function(model, ...) {
     coef = model@coef,
     se = model@se,
     pvalues = model@pvalues,
+    ci.low = model@ci.low,
+    ci.up = model@ci.up,
     gof.names = model@gof.names,
     gof = model@gof,
     gof.decimal = model@gof.decimal
